<?php
namespace Bushelpowered\Api\Crm\V1\Response;
        
class ActivityResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp, \Bushelpowered\Api\Common\HasCreatedBy, \Bushelpowered\Api\Common\HasUpdatedBy
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $activityType The type of activity: note, calltext, email, task, meeting*/
    public string $activityType;
    /** @var string $content The content of the activity, editable, 1000 character limit*/
    public string $content;
    /** @var string $customerId The UUID of the customer associated with the activity*/
    public string $customerId;
    /** @var null|string $assignedTo the UUID of the user that the task is assigned to*/
    public ?string $assignedTo = null;
    /** @var null|string $dueDate the due date of the task of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $dueDate = null;
    /** @var null|string $completedBy the UUID of the user that completed the task*/
    public ?string $completedBy = null;
    /** @var null|string $completedAt the date the task was marked as completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $completedAt = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdBy Created by UUID within the microservice.*/
    public string $createdBy;
    /** @var string $updatedBy Updated by UUID within the microservice.*/
    public string $updatedBy;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $activityType The type of activity: note, calltext, email, task, meeting
     * @param  string  $content The content of the activity, editable, 1000 character limit
     * @param  string  $customerId The UUID of the customer associated with the activity
     * @param  null|string  $assignedTo the UUID of the user that the task is assigned to
     * @param  null|string  $dueDate the due date of the task of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $completedBy the UUID of the user that completed the task
     * @param  null|string  $completedAt the date the task was marked as completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdBy Created by UUID within the microservice.
     * @param  string  $updatedBy Updated by UUID within the microservice.
     */
    public function __construct(string $id, string $tenantId, string $activityType, string $content, string $customerId, ?string $assignedTo, ?string $dueDate, ?string $completedBy, ?string $completedAt, string $createdAt, string $updatedAt, string $createdBy, string $updatedBy)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->activityType = $activityType;
        $this->content = $content;
        $this->customerId = $customerId;
        $this->assignedTo = $assignedTo;
        $this->dueDate = $dueDate;
        $this->completedBy = $completedBy;
        $this->completedAt = $completedAt;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string Created by UUID within the microservice.
     */
    public function getCreatedBy(): string
    {
        return $this->createdBy;
    }
    /**
     * @return string Updated by UUID within the microservice.
     */
    public function getUpdatedBy(): string
    {
        return $this->updatedBy;
    }
}