<?php
namespace Bushelpowered\Api\Iam\Serviceaccounts\V1\Model;
        
class ServiceAccount implements \Bushelpowered\Api\Common\HasCreatedBy, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The id of the service account*/
    public string $id;
    /** @var string $tenantId The tenant id that owns the service account*/
    public string $tenantId;
    /** @var string $name The name of the service account*/
    public string $name;
    /** @var null|string $description Description of what this service account will do*/
    public ?string $description = null;
    /** @var null|string $defaultDatasourceId The datasource to associate entities created by the service account with unless otherwise specified in each request.
    Many integration and data creation operations require a datasource to be specified.
    Has no effect on permissions or data returned from API operations.*/
    public ?string $defaultDatasourceId = null;
    /** @var string $createdBy Created by UUID within the microservice.*/
    public string $createdBy;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The id of the service account
     * @param  string  $tenantId The tenant id that owns the service account
     * @param  string  $name The name of the service account
     * @param  null|string  $description Description of what this service account will do
     * @param  null|string  $defaultDatasourceId The datasource to associate entities created by the service account with unless otherwise specified in each request.
    Many integration and data creation operations require a datasource to be specified.
    Has no effect on permissions or data returned from API operations.
     * @param  string  $createdBy Created by UUID within the microservice.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $name, ?string $description, ?string $defaultDatasourceId, string $createdBy, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->name = $name;
        $this->description = $description;
        $this->defaultDatasourceId = $defaultDatasourceId;
        $this->createdBy = $createdBy;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created by UUID within the microservice.
     */
    public function getCreatedBy(): string
    {
        return $this->createdBy;
    }
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}