<?php
namespace Bushelpowered\Api\Platform\Tenant\V1\Model;
        
class AccountRaw implements \Bushelpowered\Api\Common\Event\RawRecord
{
    /** @var string $id */
    public string $id;
    /** @var null|string $sourceName The source account name.*/
    public ?string $sourceName = null;
    /** @var string $tenantId The id of the tenant this record belongs to.*/
    public string $tenantId;
    /** @var string $datasourceId The id of the datasource this record came from.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.*/
    public string $sourceId;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $id 
     * @param  null|string  $sourceName The source account name.
     * @param  string  $tenantId The id of the tenant this record belongs to.
     * @param  string  $datasourceId The id of the datasource this record came from.
     * @param  string  $integrationId The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.
     * @param  string  $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, ?string $sourceName, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceAccountId, ?string $sourceLocationId, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->id = $id;
        $this->sourceName = $sourceName;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceLocationId = $sourceLocationId;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The id of the tenant this record belongs to.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The id of the datasource this record came from.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}